==> BittenBaum-3.01.tar.bz2: BittenBaum-3.01/core/Smdn.IO.FileSystems.Windows/Smdn.IO.FileSystems.Windows/WindowsDirectory.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2013 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.IO;

namespace Smdn.IO.FileSystems.Windows {
  public class WindowsDirectory : Directory {
    public override string Name {
      get { return info.Name; }
    }

    public override long Length {
      get { return /*info.Length*/ 0; }
    }

    public override bool Exists {
      get { return info.Exists; }
    }

    public override bool IsRoot {
      get { return info.Parent == null; }
    }

    public override Directory Parent {
      get { return (info.Parent == null) ? null : new WindowsDirectory(info.Parent); }
    }

    public override Directory Root {
      get { return new WindowsDirectory(info.Root); }
    }

    public override string FullName {
      get { return info.FullName; }
    }

    public override object RawInfo {
      get { return info; }
    }

    internal WindowsDirectory(DirectoryInfo directoryInfo)
    {
      if (directoryInfo == null)
        throw new ArgumentNullException("directoryInfo");

      this.info = directoryInfo;
    }

    public override void Refresh()
    {
      info.Refresh();
    }

    public override IEnumerable<DirectoryEntry> GetEntries(ScanDirectoryExceptionHandler exceptionHandler, Predicate<DirectoryEntry> match)
    {
      IEnumerable<FileSystemInfo> infos = null;

      try {
        // .NET 4: DirectoryInfo.EnumerateFileSystemInfos
        infos = info.GetFileSystemInfos();
      }
      catch (Exception ex) {
        if (exceptionHandler == null)
          throw ex;
        else
          exceptionHandler(this, ex);

        yield break;
      }

      foreach (var i in infos) {
        DirectoryEntry e = null;

        var f = i as FileInfo;

        if (f == null) {
          var d = i as DirectoryInfo;

          if (d == null)
            continue;
          else
            e = new WindowsDirectory(d);
        }
        else {
          e = new WindowsFile(f);
        }

        if (match == null || match(e))
          yield return e;
      }
    }

    public override IEnumerable<File> GetFiles(ScanDirectoryExceptionHandler exceptionHandler, Predicate<File> match)
    {
      IEnumerable<FileInfo> files = null;

      try {
        // .NET 4: DirectoryInfo.EnumerateFiles
        files = info.GetFiles();
      }
      catch (Exception ex) {
        if (exceptionHandler == null)
          throw ex;
        else
          exceptionHandler(this, ex);

        yield break;
      }

      foreach (var file in files) {
        var f = new WindowsFile(file);

        if (match == null || match(f))
          yield return f;
      }
    }

    public override IEnumerable<Directory> GetDirectories(ScanDirectoryExceptionHandler exceptionHandler, Predicate<Directory> match)
    {
      IEnumerable<DirectoryInfo> directories = null;

      try {
        // .NET 4: DirectoryInfo.EnumerateDirectories
        directories = info.GetDirectories();
      }
      catch (Exception ex) {
        if (exceptionHandler == null)
          throw ex;
        else
          exceptionHandler(this, ex);

        yield break;
      }

      foreach (var directory in directories) {
        var d = new WindowsDirectory(directory);

        if (match == null || match(d))
          yield return d;
      }
    }

    private DirectoryInfo info;
  }
}

==> BittenBaum-3.02.tar.bz2: BittenBaum-3.02/core/Smdn.IO.FileSystems.Windows/Smdn.IO.FileSystems.Windows/WindowsDirectory.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2014 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.IO;

namespace Smdn.IO.FileSystems.Windows {
  public class WindowsDirectory : Directory {
    public override string Name {
      get { return info.Name; }
    }

    public override long Length {
      get { return /*info.Length*/ 0L; }
    }

    public override bool Exists {
      get { return info.Exists; }
    }

    public override bool IsRoot {
      get { return info.Parent == null; }
    }

    public override Directory Parent {
      get { return (info.Parent == null) ? null : new WindowsDirectory(info.Parent); }
    }

    public override Directory Root {
      get { return new WindowsDirectory(info.Root); }
    }

    public override string FullName {
      get { return info.FullName; }
    }

    public override object RawInfo {
      get { return info; }
    }

    internal WindowsDirectory(DirectoryInfo directoryInfo)
    {
      if (directoryInfo == null)
        throw new ArgumentNullException("directoryInfo");

      this.info = directoryInfo;
    }

    public override long GetLength()
    {
      return /*info.Length*/ 0L;
    }

    public override void Refresh()
    {
      info.Refresh();
    }

    public override IEnumerable<DirectoryEntry> GetEntries(ScanDirectoryExceptionHandler exceptionHandler, Predicate<DirectoryEntry> match)
    {
      IEnumerable<FileSystemInfo> infos = null;

      try {
        // .NET 4: DirectoryInfo.EnumerateFileSystemInfos
        infos = info.GetFileSystemInfos();
      }
      catch (Exception ex) {
        if (exceptionHandler == null)
          throw ex;
        else
          exceptionHandler(this, ex);

        yield break;
      }

      foreach (var i in infos) {
        DirectoryEntry e = null;

        var f = i as FileInfo;

        if (f == null) {
          var d = i as DirectoryInfo;

          if (d == null)
            continue;
          else
            e = new WindowsDirectory(d);
        }
        else {
          e = new WindowsFile(f);
        }

        if (match == null || match(e))
          yield return e;
      }
    }

    public override IEnumerable<File> GetFiles(ScanDirectoryExceptionHandler exceptionHandler, Predicate<File> match)
    {
      IEnumerable<FileInfo> files = null;

      try {
        // .NET 4: DirectoryInfo.EnumerateFiles
        files = info.GetFiles();
      }
      catch (Exception ex) {
        if (exceptionHandler == null)
          throw ex;
        else
          exceptionHandler(this, ex);

        yield break;
      }

      foreach (var file in files) {
        var f = new WindowsFile(file);

        if (match == null || match(f))
          yield return f;
      }
    }

    public override IEnumerable<Directory> GetDirectories(ScanDirectoryExceptionHandler exceptionHandler, Predicate<Directory> match)
    {
      IEnumerable<DirectoryInfo> directories = null;

      try {
        // .NET 4: DirectoryInfo.EnumerateDirectories
        directories = info.GetDirectories();
      }
      catch (Exception ex) {
        if (exceptionHandler == null)
          throw ex;
        else
          exceptionHandler(this, ex);

        yield break;
      }

      foreach (var directory in directories) {
        var d = new WindowsDirectory(directory);

        if (match == null || match(d))
          yield return d;
      }
    }

    private DirectoryInfo info;
  }
}
